#ifndef DETECTION_H
#define DETECTION_H

#define ERR_PRINT(fmt, args...) \
	fprintf(stderr, "%s: " fmt, __func__, ## args)

#define PCI_NUM_RESOURCES 7

typedef struct _pci_resource
{
	unsigned long start;
	unsigned long len;
} pci_resource;

typedef struct _pci_device
{
	unsigned int bus_n;
	unsigned int devfn;
	
	unsigned short vendor;
	unsigned short device;
	unsigned int irq;
	pci_resource resource[PCI_NUM_RESOURCES];
	char *driver;
	
	struct _pci_device *next;
} pci_device_t;

typedef struct mapping
{
	unsigned int* start;
	unsigned long size;
	unsigned long phys;
	int type;
	unsigned int* before;
	unsigned int* after;
	char *devfile; /* needs to be free()'d */
} mapping;

extern pci_device_t *pcidev_;
extern char device_node_[256];


int create_pcilist();
void print_pcilist();
void destroy_pcilist();

pci_device_t *find_pcidev_by_addr(unsigned long addr, unsigned long size);

pci_device_t *nth_pcidev(unsigned int n);

int parse_mapping(const char *line, mapping *map);
void destroy_mapping(mapping *map);
int is_wanted_mapping(mapping *map);

int detect_devices(int opengl, int xvmc);

int find_agp_aperture(pci_resource *res);

#endif /* DETECTION_H */

