#include <stdio.h>

#include "family.h"

unsigned int get_card_family(uint32_t card_id)
{
	switch(card_id & 0x0FF0)
	{
		case 0x0020: /* TNT1/TNT2 */
		case 0x00A0: /* Aladdin TNT2 */
			return NV04;
		case 0x0100: /* GeForce 256 */
			return NV10;
		case 0x0110: /* GeForce2 MX */
		case 0x01A0: /* nForce */
		case 0x0150: /* GeForce2 */
		case 0x0170: /* GeForce4 MX */
		case 0x0180: /* GeForce4 MX (8x AGP) */
		case 0x01F0: /* nForce2 */
			return NV15;
		case 0x0200: /* GeForce3 */
		case 0x0250: /* GeForce4 Ti */
		case 0x0280: /* GeForce4 Ti (8x AGP) */
			return NV20;
		case 0x0300: /* GeForceFX 5800 */
		case 0x0310: /* GeForceFX 5600 */
		case 0x0320: /* GeForceFX 5200 */
		case 0x0330: /* GeForceFX 5900 */
		case 0x0340: /* GeForceFX 5700 */
			return NV30;
		case 0x0040: /* GeForce 6800 */
		case 0x00C0: /* GeForce 6800 */
		case 0x0120: /* GeForce 6800 */
		case 0x0210: /* GeForce 6800 */
		case 0x0140: /* GeForce 6600 */
		case 0x0160: /* GeForce 6200 */
		case 0x0220: /* GeForce 6200 */
		case 0x0240: /* GeForce 6100 */
			return NV40;
		case 0x01D0: /* GeForce 7200, 7300, 7400 */
		case 0x0090: /* GeForce 7800 */
		case 0x0290: /* GeForce 7900 */
		case 0x02E0: /* GeForce 7600 */
		case 0x0390: /* GeForce 7600 */
		case 0x07E0: /* GeForce 70xx/71xx */
		case 0x0530: /* GeForce 70xx/71xx */
			return G70;
		case 0x00F0: /* misc PCI-E cards */
			switch(card_id&0xFF)
			{
				case 0xFF: /* Geforce 4300 */
					return NV15;
				case 0xFA: /* GeForceFX 5750 */
				case 0xFB: /* GeForceFX 5900 */
				case 0xFC: /* QuadroFX 330/GeForceFX 5300 */
				case 0xFD: /* QuadroFX 330/NVS 280 */
				case 0xFE: /* QuadroFX 1300 */
					return NV30;
				case 0xF0: /* GeForce 6800 */
				case 0xF1: /* GeForce 6600 */
				case 0xF2: /* GeForce 6600 */
				case 0xF3: /* GeForce 6200 */
				case 0xF4: /* GeForce 6600 */
				case 0xF6: /* GeForce 6600 */
				case 0xF7: /* guess */
				case 0xF8: /* QuadroFX 3400/4400 */
				case 0xF9: /* GeForce 6800 */
					return NV40;
				case 0xF5: /* GeForce 7800 */
					return G70;
			}
			break;
		case 0x190: /* GeForce 8800 */
		case 0x400: /* GeForce 8400/8600 */
		case 0x420: /* GeForce 8400/8500 */
		case 0x600: /* GeForce 8800 */
		case 0x610: /* GeForce 8800 */
		case 0x620: /* GeForce 9600 */
			return G80;
		default:
			printf("Unknown card\n");
			return G70;
	}
	return -1;
}
